#
# Name:    Makehead.sol
#
# Purpose: This file is used to customize operating system and installation
#          dependent features of the MX makefiles.  This version is customized
#          for Solaris 2.
#
# Normally, the only things that end users may have to modify in this file are
# the definitions of INCLUDES, LIB_DIRS, and LIBRARIES.
#

#
INCLUDES	= $(MX_INCLUDES)
#
#LIB_DIRS	= 
#LIBRARIES	= -lm -lnsl -lsocket -lposix4

LIB_DIRS	= -L$(MX_LIB_DIR) $(EPICS_LIB_DIRS)
LIBRARIES	= $(EPICS_LIBRARIES) -lm -lnsl -lsocket -lposix4

#
# Motor will be linked with the bundled copy of 'editline' if you use the
# following definitions.
#
READLINE_LIB_DIRS = -L../tools/unix/src/editline
READLINE_LIBRARIES = -ledit

#
# If you prefer to link motor to GNU Readline instead, uncomment the
# following definitions.
#
#READLINE_LIB_DIRS = -L/usr/local/lib
#READLINE_LIBRARIES = -lreadline -lcurses

#
# You may also need to modify some of the following definitions, depending
# on the drivers you plan to use.
#

#
# EPICS includes and libraries.
#
EPICS_ARCH	= solaris
EPICS_TOP	= /usr/local/epics
EPICS_INCLUDES	= -I$(EPICS_TOP)/base/include \
			-I$(EPICS_TOP)/extensions/include
EPICS_LIB_DIRS	= -L$(EPICS_TOP)/extensions/lib/$(EPICS_ARCH) \
			-L$(EPICS_TOP)/base/lib/$(EPICS_ARCH)
EPICS_LIBRARIES = -lezca -lca -lCom

#
#========================================================================
#
# Generally, you should not have to modify anything after this point.
#

#
# Sun Sparcstation 10 with CC (Sparc Compiler 4.0) under Solaris 2.5
#
CC		= /opt/SUNWspro/bin/cc

CFLAGS		= -g -KPIC $(INCLUDES) -DOS_SOLARIS2 $(EXTRA_FLAGS) -DDEBUG

CFLAGS_EPICS	= $(CFLAGS)

CFLAGS_MX_VERS  = $(CFLAGS) -DMX_MAJOR_VERSION=$(MX_MAJOR_VERSION) \
			-DMX_MINOR_VERSION=$(MX_MINOR_VERSION) \
			-DMX_UPDATE_VERSION=$(MX_UPDATE_VERSION)

CFLAGS_MAKEDEPEND = $(CFLAGS) $(EPICS_INCLUDES) $(READLINE_INCLUDES)

COMPILE		= $(CC) -c
DEFINE		= -D
MAKEDEPEND	= $(CC) -xM1 $(CFLAGS_MAKEDEPEND) *.c > Makefile.dep

#
#
RM		= rm -f
#
MAKE		= make
#
OBJ		= o
#
#---------------------------------------------------
#
MX_LIB_DIR	= ../libMx
MX_INC_DIR	= $(MX_LIB_DIR)
MX_INCLUDES	= -I$(MX_INC_DIR)

MX_LIBRARY_PATH	= $(MX_LIB_DIR)/$(MX_LIBRARY_NAME)

MX_SONAME	= libMx.so.$(MX_MAJOR_VERSION)
MX_LIBRARY_NAME	= $(MX_SONAME)

MX_LIBRARY_DELETE = rm $(MX_LIBRARY_NAME) libMx.so libMx.a

MX_LIBRARY_BUILD  = ld -G -o $(MX_LIBRARY_NAME) \
			$(LIB_DIRS) $(MX_LIB_OBJS) $(LIBRARIES) -lc
MX_LIBRARY_BUILD2 = ln -sf $(MX_LIBRARY_NAME) libMx.so
MX_LIBRARY_BUILD3 = ar rcs libMx.a $(MX_LIB_OBJS)

MX_LIBRARY_INSTALL  = -mkdir $(INSTALL_DIR)/bin
MX_LIBRARY_INSTALL2 = -mkdir $(INSTALL_DIR)/etc
MX_LIBRARY_INSTALL3 = -mkdir $(INSTALL_DIR)/include
MX_LIBRARY_INSTALL4 = -mkdir $(INSTALL_DIR)/lib
MX_LIBRARY_INSTALL5 = -mkdir $(INSTALL_DIR)/log
MX_LIBRARY_INSTALL6 = -mkdir $(INSTALL_DIR)/run
MX_LIBRARY_INSTALL7 = -mkdir $(INSTALL_DIR)/sbin
MX_LIBRARY_INSTALL8 = -mkdir $(INSTALL_DIR)/state
MX_LIBRARY_INSTALL9 = /usr/ucb/install -m 644 *.h $(INSTALL_DIR)/include 
MX_LIBRARY_INSTALL10 = \
	/usr/ucb/install -m 644 $(MX_LIBRARY_NAME) $(INSTALL_DIR)/lib 
MX_LIBRARY_INSTALL11 = /usr/ucb/install -m 644 libMx.a $(INSTALL_DIR)/lib 
MX_LIBRARY_INSTALL12 = -( cd $(INSTALL_DIR)/lib ; rm libMx.so )
MX_LIBRARY_INSTALL13 = \
	( cd $(INSTALL_DIR)/lib ; ln -sf $(MX_LIBRARY_NAME) libMx.so )
MX_LIBRARY_INSTALL14 = touch $(INSTALL_DIR)/etc/motor.dat
MX_LIBRARY_INSTALL15 = touch $(INSTALL_DIR)/etc/scan.dat
MX_LIBRARY_INSTALL16 = \
	/usr/ucb/install -m 755 ../plotgnu/plotgnu.pl $(INSTALL_DIR)/bin 
MX_LIBRARY_INSTALL17 = \
	/usr/ucb/install -m 755 ../plotgnu/showdata $(INSTALL_DIR)/bin 
MX_LIBRARY_INSTALL18 = \
	/usr/ucb/install -m 755 ../plotgnu/showplot $(INSTALL_DIR)/bin 
MX_LIBRARY_INSTALL19 = \
	/usr/ucb/install -m 755 ../plotgnu/plot2ps $(INSTALL_DIR)/bin 
#
#---------------------------------------------------
#

MOTOR_NAME	= motor.shared
MOTOR_NAME2	= motor.static
#
MOTOR_BUILD	= $(CC) $(CFLAGS) -o $(MOTOR_NAME) $(MOTOR_OBJS) \
			$(LIB_DIRS) $(READLINE_LIB_DIRS) \
			-lMx $(LIBRARIES) $(READLINE_LIBRARIES)
MOTOR_BUILD2	= $(CC) $(CFLAGS) -o $(MOTOR_NAME2) $(MOTOR_OBJS) \
			$(LIB_DIRS) $(READLINE_LIB_DIRS) \
			../libMx/libMx.a $(LIBRARIES) $(READLINE_LIBRARIES)

MOTOR_INSTALL   = /usr/ucb/install -m 755 $(MOTOR_NAME) $(INSTALL_DIR)/bin 
MOTOR_INSTALL2  = /usr/ucb/install -m 755 $(MOTOR_NAME2) $(INSTALL_DIR)/bin 
MOTOR_INSTALL3  = /usr/ucb/install -m 755 ../scripts/motor $(INSTALL_DIR)/bin 
MOTOR_INSTALL4  = \
	/usr/ucb/install -m 755 ../scripts/motor_xterm $(INSTALL_DIR)/bin 
#
#---------------------------------------------------
#
SERVER_NAME	= mxserver
SERVER_BUILD	= $(CC) $(CFLAGS) -o $(SERVER_NAME) $(SERVER_OBJS) \
			$(LIB_DIRS) -lMx $(LIBRARIES)

SERVER_INSTALL  = /usr/ucb/install -m 755 $(SERVER_NAME) $(INSTALL_DIR)/sbin 
SERVER_INSTALL2 = \
	/usr/ucb/install -m 755 ../scripts/startmxserver $(INSTALL_DIR)/sbin 
SERVER_INSTALL3 = /usr/ucb/install -m 755 ../scripts/mx $(INSTALL_DIR)/sbin 
SERVER_INSTALL4 = touch $(INSTALL_DIR)/etc/mxserver.dat
SERVER_INSTALL5 = touch $(INSTALL_DIR)/etc/mxserver.acl
#
#---------------------------------------------------
#
UPDATE_NAME	= mxupdate
UPDATE_BUILD	= $(CC) $(CFLAGS) -o $(UPDATE_NAME) $(UPDATE_OBJS) \
			$(LIB_DIRS) -lMx $(LIBRARIES)

UPDATE_INSTALL  = /usr/ucb/install -m 755 $(UPDATE_NAME) $(INSTALL_DIR)/sbin 
UPDATE_INSTALL2 = \
	/usr/ucb/install -m 755 ../scripts/startmxupdate $(INSTALL_DIR)/sbin 
UPDATE_INSTALL3 = touch $(INSTALL_DIR)/etc/mxupdate.dat
#
#---------------------------------------------------
#
# See libMx/Makehead.sgi for why this is here.
#
MX_LIB_OBJS = $(MX_LIB_SRCS:.c=.$(OBJ))
MOTOR_OBJS  = $(MOTOR_SRCS:.c=.$(OBJ))
SERVER_OBJS = $(SERVER_SRCS:.c=.$(OBJ))
UPDATE_OBJS = $(UPDATE_SRCS:.c=.$(OBJ))

