/*
 * Name:    mhome.c
 *
 * Purpose: Command to perform a home search on a motor.
 *
 * Author:  William Lavender
 *
 *-------------------------------------------------------------------------
 *
 * Copyright 1999 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#include <stdio.h>
#include <stdlib.h>

#include "motor.h"

int
motor_home_fn( int argc, char *argv[] )
{
	const char cname[] = "home";

	MX_RECORD *record;
	int direction;
	char *endptr;
	mx_status_type mx_status;

	static char usage[] =
"Usage:  home 'motorname' 'direction' -  Perform a home search on 'motorname'\n"
"\n"
"  Normally, direction > 0 causes a search in the positive direction,\n"
"  while direction < 0 causes a search in the negative direction.  Some\n"
"  drivers that can't do a home search will perform some other operation\n"
"  related to position calibration.  You must examine the individual driver\n"
"  to see exactly what it will do.  In all cases, direction == 0 is performs\n"
"  some driver specific function.\n";

	if ( argc != 4 ) {
		fprintf(output, "%s\n", usage);
		return FAILURE;
	}

	record = mx_get_record( motor_record_list, argv[2] );

	if ( record == (MX_RECORD *) NULL ) {
		fprintf(output,"%s: invalid motor name '%s'\n",cname,argv[2]);
		return FAILURE;
	}

	/* Is this a motor? */

	if ( record->mx_class != MXC_MOTOR ) {
		fprintf(output,"%s: '%s' is not a motor.\n",cname,argv[2]);
		return FAILURE;
	}

	direction = (int) strtol( argv[3], &endptr, 10 );

	if ( *endptr != '\0' ) {
		fprintf(output,
			"%s: specified direction '%s' is not a number.\n",
			cname, argv[3] );
		return FAILURE;
	}

	mx_status = mx_motor_find_home_position( record, direction );

	if ( mx_status.code == MXE_SUCCESS ) {
		return SUCCESS;
	} else {
		return FAILURE;
	}
}
